import os
import discord

import ui

client = discord.Client()

@client.event
async def on_ready():
    print(f'{client}: Ready for Testing')

@client.event
async def on_message(message):
    if message.author == client.user:
        return

    # Test alerts
    if message.content.startswith('?alert'):
        await message.channel.send(embed=ui.Alert("primary", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("secondary", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("success", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("danger", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("warning", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("info", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("light", "This is a test alert", "Check it out!"))
        await message.channel.send(embed=ui.Alert("dark", "This is a test alert", "Check it out!"))

client.run(os.getenv("TOKEN"))



from setuptools import setup
import os


version = os.getenv("VERSION").split("/")[-1][1:]


with open('requirements.txt') as file:
  requirements = file.read().splitlines()


with open('README.md') as file:
    readme = file.read()


setup(name='blurple.py',
      author='LeptoFlare',
      url='https://github.com/LeptoFlare/blurple.py',
      project_urls={
        "Issues": "https://github.com/LeptoFlare/blurple.py/issues",
        "Docs": "https://lepto.tech/blurple.py",
      },
      version=version,
      packages=['blurple'],
      license='MIT',
      description='A framework built on discord.py',
      long_description=readme,
      long_description_content_type="text/markdown",
      include_package_data=True,
      install_requires=requirements,
      classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
      ]
)